@@ -4,6 +4,7 @@ from typing import Optional
 import click
 
 from hapless import config
+from hapless.formatters import JSONFormatter, TableFormatter
 from hapless.main import Hapless
 from hapless.utils import validate_signal
 
@@ -31,33 +32,48 @@ def get_or_exit(hap_alias: str):
 @click.group(invoke_without_command=True)
 @click.version_option(message="hapless, version %(version)s")
 @click.option("-v", "--verbose", is_flag=True, default=False)
+@click.option(
+    "--json", "json_output", is_flag=True, default=False, help="Output in JSON format."
+)
 @click.pass_context
-def cli(ctx, verbose):
+def cli(ctx, verbose: bool, json_output: bool):
     if ctx.invoked_subcommand is None:
-        _status(None, verbose=verbose)
+        _status(None, verbose=verbose, json_output=json_output)
 
 
 @cli.command(short_help="Display information about haps.")
 @click.argument("hap_alias", metavar="hap", required=False)
 @click.option("-v", "--verbose", is_flag=True, default=False)
-def status(hap_alias, verbose):
-    _status(hap_alias, verbose)
+@click.option(
+    "--json", "json_output", is_flag=True, default=False, help="Output in JSON format."
+)
+def status(hap_alias: Optional[str], verbose: bool, json_output: bool):
+    _status(hap_alias, verbose, json_output=json_output)
 
 
 @cli.command(short_help="Same as a status.")
 @click.argument("hap_alias", metavar="hap", required=False)
 @click.option("-v", "--verbose", is_flag=True, default=False)
-def show(hap_alias, verbose):
-    _status(hap_alias, verbose)
+@click.option(
+    "--json", "json_output", is_flag=True, default=False, help="Output in JSON format."
+)
+def show(hap_alias: Optional[str], verbose: bool, json_output: bool):
+    _status(hap_alias, verbose, json_output=json_output)
 
 
-def _status(hap_alias: Optional[str] = None, verbose: bool = False):
+def _status(
+    hap_alias: Optional[str] = None,
+    verbose: bool = False,
+    json_output: bool = False,
+):
+    formatter_cls = JSONFormatter if json_output else TableFormatter
+    formatter = formatter_cls(verbose=verbose)
     if hap_alias is not None:
         hap = get_or_exit(hap_alias)
-        hapless.show(hap, verbose=verbose)
+        hapless.show(hap, formatter=formatter)
     else:
         haps = hapless.get_haps(accessible_only=False)
-        hapless.stats(haps, verbose=verbose)
+        hapless.stats(haps, formatter=formatter)
 
 
 @cli.command(short_help="Output logs for a hap.")
